@@ -15,10 +15,11 @@
 // TODO(ctiller): Add a unit test suite for these filters once it's practical to
 // mock transport operations.
 
-#include <grpc/support/port_platform.h>
-
 #include "src/core/ext/filters/channel_idle/legacy_channel_idle_filter.h"
 
+#include <grpc/impl/channel_arg_names.h>
+#include <grpc/support/port_platform.h>
+
 #include <functional>
 #include <utility>
 
@@ -27,20 +28,11 @@
 #include "absl/random/random.h"
 #include "absl/status/statusor.h"
 #include "absl/types/optional.h"
-
-#include <grpc/impl/channel_arg_names.h>
-
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/channel/promise_based_filter.h"
 #include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/debug/trace.h"
 #include "src/core/lib/experiments/experiments.h"
-#include "src/core/lib/gprpp/debug_location.h"
-#include "src/core/lib/gprpp/no_destruct.h"
-#include "src/core/lib/gprpp/orphanable.h"
-#include "src/core/lib/gprpp/per_cpu.h"
-#include "src/core/lib/gprpp/status_helper.h"
-#include "src/core/lib/gprpp/sync.h"
 #include "src/core/lib/iomgr/closure.h"
 #include "src/core/lib/iomgr/error.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
@@ -54,6 +46,12 @@
 #include "src/core/lib/surface/channel_stack_type.h"
 #include "src/core/lib/transport/http2_errors.h"
 #include "src/core/lib/transport/metadata_batch.h"
+#include "src/core/util/debug_location.h"
+#include "src/core/util/no_destruct.h"
+#include "src/core/util/orphanable.h"
+#include "src/core/util/per_cpu.h"
+#include "src/core/util/status_helper.h"
+#include "src/core/util/sync.h"
 
 namespace grpc_core {
 
@@ -207,7 +205,7 @@ void LegacyMaxAgeFilter::PostInit() {
           // OnDone -- close the connection if the promise completed
           // successfully.
           // (if it did not, it was cancelled)
-          if (status.ok()) CloseChannel();
+          if (status.ok()) CloseChannel("max connection age");
         },
         std::move(arena)));
   }
@@ -273,16 +271,16 @@ void LegacyChannelIdleFilter::StartIdleTimer() {
   activity_.Set(MakeActivity(
       std::move(promise), ExecCtxWakeupScheduler{},
       [channel_stack, this](absl::Status status) {
-        if (status.ok()) CloseChannel();
+        if (status.ok()) CloseChannel("connection idle");
       },
       std::move(arena)));
 }
 
-void LegacyChannelIdleFilter::CloseChannel() {
+void LegacyChannelIdleFilter::CloseChannel(absl::string_view reason) {
   auto* op = grpc_make_transport_op(nullptr);
   op->disconnect_with_error = grpc_error_set_int(
-      GRPC_ERROR_CREATE("enter idle"),
-      StatusIntProperty::ChannelConnectivityState, GRPC_CHANNEL_IDLE);
+      GRPC_ERROR_CREATE(reason), StatusIntProperty::ChannelConnectivityState,
+      GRPC_CHANNEL_IDLE);
   // Pass the transport op down to the channel stack.
   auto* elem = grpc_channel_stack_element(channel_stack_, 0);
   elem->filter->start_transport_op(elem, op);
