@@ -14,6 +14,11 @@
 
 #include "src/core/ext/transport/chaotic_good/server_transport.h"
 
+#include <grpc/event_engine/event_engine.h>
+#include <grpc/grpc.h>
+#include <grpc/slice.h>
+#include <grpc/support/port_platform.h>
+
 #include <memory>
 #include <string>
 #include <tuple>
@@ -24,18 +29,11 @@
 #include "absl/random/random.h"
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
-
-#include <grpc/event_engine/event_engine.h>
-#include <grpc/grpc.h>
-#include <grpc/slice.h>
-#include <grpc/support/port_platform.h>
-
 #include "src/core/ext/transport/chaotic_good/chaotic_good_transport.h"
 #include "src/core/ext/transport/chaotic_good/frame.h"
 #include "src/core/ext/transport/chaotic_good/frame_header.h"
 #include "src/core/ext/transport/chttp2/transport/hpack_encoder.h"
 #include "src/core/lib/event_engine/event_engine_context.h"
-#include "src/core/lib/gprpp/ref_counted_ptr.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/promise/activity.h"
 #include "src/core/lib/promise/event_engine_wakeup_scheduler.h"
@@ -48,6 +46,7 @@
 #include "src/core/lib/slice/slice.h"
 #include "src/core/lib/slice/slice_buffer.h"
 #include "src/core/lib/transport/promise_endpoint.h"
+#include "src/core/util/ref_counted_ptr.h"
 
 namespace grpc_core {
 namespace chaotic_good {
@@ -72,13 +71,10 @@ auto ChaoticGoodServerTransport::TransportWriteLoop(
 }
 
 auto ChaoticGoodServerTransport::PushFragmentIntoCall(
-    CallInitiator call_initiator, ClientFragmentFrame frame,
-    uint32_t stream_id) {
+    CallInitiator call_initiator, ClientFragmentFrame frame) {
   DCHECK(frame.headers == nullptr);
-  if (GRPC_TRACE_FLAG_ENABLED(chaotic_good)) {
-    LOG(INFO) << "CHAOTIC_GOOD: PushFragmentIntoCall: frame="
-              << frame.ToString();
-  }
+  GRPC_TRACE_LOG(chaotic_good, INFO)
+      << "CHAOTIC_GOOD: PushFragmentIntoCall: frame=" << frame.ToString();
   return Seq(If(
                  frame.message.has_value(),
                  [&call_initiator, &frame]() mutable {
@@ -86,17 +82,15 @@ auto ChaoticGoodServerTransport::PushFragmentIntoCall(
                        std::move(frame.message->message));
                  },
                  []() -> StatusFlag { return Success{}; }),
-             [this, call_initiator, end_of_stream = frame.end_of_stream,
-              stream_id](StatusFlag status) mutable -> StatusFlag {
+             [call_initiator, end_of_stream = frame.end_of_stream](
+                 StatusFlag status) mutable -> StatusFlag {
                if (!status.ok() && GRPC_TRACE_FLAG_ENABLED(chaotic_good)) {
                  LOG(INFO) << "CHAOTIC_GOOD: Failed PushFragmentIntoCall";
                }
                if (end_of_stream || !status.ok()) {
                  call_initiator.FinishSends();
-                 // We have received end_of_stream. It is now safe to remove
-                 // the call from the stream map.
-                 MutexLock lock(&mu_);
-                 stream_map_.erase(stream_id);
+                 // Note that we cannot remove from the stream map yet, as we
+                 // may yet receive a cancellation.
                }
                return Success{};
              });
@@ -104,17 +98,16 @@ auto ChaoticGoodServerTransport::PushFragmentIntoCall(
 
 auto ChaoticGoodServerTransport::MaybePushFragmentIntoCall(
     absl::optional<CallInitiator> call_initiator, absl::Status error,
-    ClientFragmentFrame frame, uint32_t stream_id) {
+    ClientFragmentFrame frame) {
   return If(
       call_initiator.has_value() && error.ok(),
-      [this, &call_initiator, &frame, &stream_id]() {
+      [this, &call_initiator, &frame]() {
         return Map(
             call_initiator->SpawnWaitable(
                 "push-fragment",
-                [call_initiator, frame = std::move(frame), stream_id,
-                 this]() mutable {
-                  return call_initiator->CancelIfFails(PushFragmentIntoCall(
-                      *call_initiator, std::move(frame), stream_id));
+                [call_initiator, frame = std::move(frame), this]() mutable {
+                  return call_initiator->CancelIfFails(
+                      PushFragmentIntoCall(*call_initiator, std::move(frame)));
                 }),
             [](StatusFlag status) { return StatusCast<absl::Status>(status); });
       },
@@ -131,22 +124,37 @@ auto ChaoticGoodServerTransport::MaybePushFragmentIntoCall(
       });
 }
 
+namespace {
+auto BooleanSuccessToTransportErrorCapturingInitiator(CallInitiator initiator) {
+  return [initiator = std::move(initiator)](bool success) {
+    return success ? absl::OkStatus()
+                   : absl::UnavailableError("Transport closed.");
+  };
+}
+}  // namespace
+
 auto ChaoticGoodServerTransport::SendFragment(
     ServerFragmentFrame frame, MpscSender<ServerFrame> outgoing_frames,
     CallInitiator call_initiator) {
-  if (GRPC_TRACE_FLAG_ENABLED(chaotic_good)) {
-    LOG(INFO) << "CHAOTIC_GOOD: SendFragment: frame=" << frame.ToString();
-  }
+  GRPC_TRACE_LOG(chaotic_good, INFO)
+      << "CHAOTIC_GOOD: SendFragment: frame=" << frame.ToString();
   // Capture the call_initiator to ensure the underlying call spine is alive
   // until the outgoing_frames.Send promise completes.
   return Map(outgoing_frames.Send(std::move(frame)),
-             [call_initiator](bool success) -> absl::Status {
-               if (!success) {
-                 // Failed to send outgoing frame.
-                 return absl::UnavailableError("Transport closed.");
-               }
-               return absl::OkStatus();
-             });
+             BooleanSuccessToTransportErrorCapturingInitiator(
+                 std::move(call_initiator)));
+}
+
+auto ChaoticGoodServerTransport::SendFragmentAcked(
+    ServerFragmentFrame frame, MpscSender<ServerFrame> outgoing_frames,
+    CallInitiator call_initiator) {
+  GRPC_TRACE_LOG(chaotic_good, INFO)
+      << "CHAOTIC_GOOD: SendFragmentAcked: frame=" << frame.ToString();
+  // Capture the call_initiator to ensure the underlying call spine is alive
+  // until the outgoing_frames.Send promise completes.
+  return Map(outgoing_frames.SendAcked(std::move(frame)),
+             BooleanSuccessToTransportErrorCapturingInitiator(
+                 std::move(call_initiator)));
 }
 
 auto ChaoticGoodServerTransport::SendCallBody(
@@ -173,7 +181,8 @@ auto ChaoticGoodServerTransport::SendCallBody(
         frame.message =
             FragmentMessage(std::move(message), padding, message_length);
         frame.stream_id = stream_id;
-        return SendFragment(std::move(frame), outgoing_frames, call_initiator);
+        return SendFragmentAcked(std::move(frame), outgoing_frames,
+                                 call_initiator);
       });
 }
 
@@ -185,10 +194,9 @@ auto ChaoticGoodServerTransport::SendCallInitialMetadataAndBody(
       call_initiator.PullServerInitialMetadata(),
       [stream_id, outgoing_frames, call_initiator,
        this](absl::optional<ServerMetadataHandle> md) mutable {
-        if (GRPC_TRACE_FLAG_ENABLED(chaotic_good)) {
-          LOG(INFO) << "CHAOTIC_GOOD: SendCallInitialMetadataAndBody: md="
-                    << (md.has_value() ? (*md)->DebugString() : "null");
-        }
+        GRPC_TRACE_LOG(chaotic_good, INFO)
+            << "CHAOTIC_GOOD: SendCallInitialMetadataAndBody: md="
+            << (md.has_value() ? (*md)->DebugString() : "null");
         return If(
             md.has_value(),
             [&md, stream_id, &outgoing_frames, &call_initiator, this]() {
@@ -207,26 +215,27 @@ auto ChaoticGoodServerTransport::SendCallInitialMetadataAndBody(
 auto ChaoticGoodServerTransport::CallOutboundLoop(
     uint32_t stream_id, CallInitiator call_initiator) {
   auto outgoing_frames = outgoing_frames_.MakeSender();
-  return Seq(
-      Map(SendCallInitialMetadataAndBody(stream_id, outgoing_frames,
-                                         call_initiator),
-          [stream_id](absl::Status main_body_result) {
-            if (GRPC_TRACE_FLAG_ENABLED(chaotic_good)) {
-              VLOG(2) << "CHAOTIC_GOOD: CallOutboundLoop: stream_id="
-                      << stream_id << " main_body_result=" << main_body_result;
-            }
-            return Empty{};
-          }),
-      call_initiator.PullServerTrailingMetadata(),
-      // Capture the call_initator to ensure the underlying call_spine
-      // is alive until the SendFragment promise completes.
-      [stream_id, outgoing_frames,
-       call_initiator](ServerMetadataHandle md) mutable {
-        ServerFragmentFrame frame;
-        frame.trailers = std::move(md);
-        frame.stream_id = stream_id;
-        return SendFragment(std::move(frame), outgoing_frames, call_initiator);
-      });
+  return GRPC_LATENT_SEE_PROMISE(
+      "CallOutboundLoop",
+      Seq(Map(SendCallInitialMetadataAndBody(stream_id, outgoing_frames,
+                                             call_initiator),
+              [stream_id](absl::Status main_body_result) {
+                GRPC_TRACE_VLOG(chaotic_good, 2)
+                    << "CHAOTIC_GOOD: CallOutboundLoop: stream_id=" << stream_id
+                    << " main_body_result=" << main_body_result;
+                return Empty{};
+              }),
+          call_initiator.PullServerTrailingMetadata(),
+          // Capture the call_initator to ensure the underlying call_spine
+          // is alive until the SendFragment promise completes.
+          [stream_id, outgoing_frames,
+           call_initiator](ServerMetadataHandle md) mutable {
+            ServerFragmentFrame frame;
+            frame.trailers = std::move(md);
+            frame.stream_id = stream_id;
+            return SendFragment(std::move(frame), outgoing_frames,
+                                call_initiator);
+          }));
 }
 
 auto ChaoticGoodServerTransport::DeserializeAndPushFragmentToNewCall(
@@ -246,10 +255,11 @@ auto ChaoticGoodServerTransport::DeserializeAndPushFragmentToNewCall(
     call_initiator.emplace(std::move(call.initiator));
     auto add_result = NewStream(frame_header.stream_id, *call_initiator);
     if (add_result.ok()) {
-      call_destination_->StartCall(std::move(call.handler));
       call_initiator->SpawnGuarded(
           "server-write", [this, stream_id = frame_header.stream_id,
-                           call_initiator = *call_initiator]() {
+                           call_initiator = *call_initiator,
+                           call_handler = std::move(call.handler)]() mutable {
+            call_destination_->StartCall(std::move(call_handler));
             return CallOutboundLoop(stream_id, call_initiator);
           });
     } else {
@@ -258,8 +268,7 @@ auto ChaoticGoodServerTransport::DeserializeAndPushFragmentToNewCall(
     }
   }
   return MaybePushFragmentIntoCall(std::move(call_initiator), std::move(status),
-                                   std::move(fragment_frame),
-                                   frame_header.stream_id);
+                                   std::move(fragment_frame));
 }
 
 auto ChaoticGoodServerTransport::DeserializeAndPushFragmentToExistingCall(
@@ -274,58 +283,63 @@ auto ChaoticGoodServerTransport::DeserializeAndPushFragmentToExistingCall(
       frame_header, std::move(buffers), arena, fragment_frame,
       FrameLimits{1024 * 1024 * 1024, aligned_bytes_ - 1});
   return MaybePushFragmentIntoCall(std::move(call_initiator), std::move(status),
-                                   std::move(fragment_frame),
-                                   frame_header.stream_id);
+                                   std::move(fragment_frame));
 }
 
 auto ChaoticGoodServerTransport::ReadOneFrame(ChaoticGoodTransport& transport) {
-  return TrySeq(
-      transport.ReadFrameBytes(),
-      [this, transport =
-                 &transport](std::tuple<FrameHeader, BufferPair> frame_bytes) {
-        const auto& frame_header = std::get<0>(frame_bytes);
-        auto& buffers = std::get<1>(frame_bytes);
-        return Switch(
-            frame_header.type,
-            Case(FrameType::kSettings,
-                 []() -> absl::Status {
-                   return absl::InternalError("Unexpected settings frame");
-                 }),
-            Case(FrameType::kFragment,
-                 [this, &frame_header, &buffers, transport]() {
-                   return If(
-                       frame_header.flags.is_set(0),
-                       [this, &frame_header, &buffers, transport]() {
-                         return DeserializeAndPushFragmentToNewCall(
-                             frame_header, std::move(buffers), *transport);
-                       },
-                       [this, &frame_header, &buffers, transport]() {
-                         return DeserializeAndPushFragmentToExistingCall(
-                             frame_header, std::move(buffers), *transport);
-                       });
-                 }),
-            Case(FrameType::kCancel,
-                 [this, &frame_header]() {
-                   absl::optional<CallInitiator> call_initiator =
-                       ExtractStream(frame_header.stream_id);
-                   return If(
-                       call_initiator.has_value(),
-                       [&call_initiator]() {
-                         auto c = std::move(*call_initiator);
-                         return c.SpawnWaitable("cancel", [c]() mutable {
-                           c.Cancel();
-                           return absl::OkStatus();
-                         });
-                       },
-                       []() -> absl::Status { return absl::OkStatus(); });
-                 }),
-            Default([frame_header]() {
-              return absl::InternalError(
-                  absl::StrCat("Unexpected frame type: ",
-                               static_cast<uint8_t>(frame_header.type)));
-            }));
-      },
-      []() -> LoopCtl<absl::Status> { return Continue{}; });
+  return GRPC_LATENT_SEE_PROMISE(
+      "ReadOneFrame",
+      TrySeq(
+          transport.ReadFrameBytes(),
+          [this, transport = &transport](
+              std::tuple<FrameHeader, BufferPair> frame_bytes) {
+            const auto& frame_header = std::get<0>(frame_bytes);
+            auto& buffers = std::get<1>(frame_bytes);
+            return Switch(
+                frame_header.type,
+                Case(FrameType::kSettings,
+                     []() -> absl::Status {
+                       return absl::InternalError("Unexpected settings frame");
+                     }),
+                Case(FrameType::kFragment,
+                     [this, &frame_header, &buffers, transport]() {
+                       return If(
+                           frame_header.flags.is_set(0),
+                           [this, &frame_header, &buffers, transport]() {
+                             return DeserializeAndPushFragmentToNewCall(
+                                 frame_header, std::move(buffers), *transport);
+                           },
+                           [this, &frame_header, &buffers, transport]() {
+                             return DeserializeAndPushFragmentToExistingCall(
+                                 frame_header, std::move(buffers), *transport);
+                           });
+                     }),
+                Case(FrameType::kCancel,
+                     [this, &frame_header]() {
+                       absl::optional<CallInitiator> call_initiator =
+                           ExtractStream(frame_header.stream_id);
+                       GRPC_TRACE_LOG(chaotic_good, INFO)
+                           << "Cancel stream " << frame_header.stream_id
+                           << (call_initiator.has_value() ? " (active)"
+                                                          : " (not found)");
+                       return If(
+                           call_initiator.has_value(),
+                           [&call_initiator]() {
+                             auto c = std::move(*call_initiator);
+                             return c.SpawnWaitable("cancel", [c]() mutable {
+                               c.Cancel();
+                               return absl::OkStatus();
+                             });
+                           },
+                           []() -> absl::Status { return absl::OkStatus(); });
+                     }),
+                Default([frame_header]() {
+                  return absl::InternalError(
+                      absl::StrCat("Unexpected frame type: ",
+                                   static_cast<uint8_t>(frame_header.type)));
+                }));
+          },
+          []() -> LoopCtl<absl::Status> { return Continue{}; }));
 }
 
 auto ChaoticGoodServerTransport::TransportReadLoop(
@@ -340,10 +354,9 @@ auto ChaoticGoodServerTransport::OnTransportActivityDone(
     absl::string_view activity) {
   return [self = RefAsSubclass<ChaoticGoodServerTransport>(),
           activity](absl::Status status) {
-    if (GRPC_TRACE_FLAG_ENABLED(chaotic_good)) {
-      LOG(INFO) << "CHAOTIC_GOOD: OnTransportActivityDone: activity="
-                << activity << " status=" << status;
-    }
+    GRPC_TRACE_LOG(chaotic_good, INFO)
+        << "CHAOTIC_GOOD: OnTransportActivityDone: activity=" << activity
+        << " status=" << status;
     self->AbortWithError();
   };
 }
@@ -363,12 +376,18 @@ ChaoticGoodServerTransport::ChaoticGoodServerTransport(
   auto transport = MakeRefCounted<ChaoticGoodTransport>(
       std::move(control_endpoint), std::move(data_endpoint),
       std::move(hpack_parser), std::move(hpack_encoder));
-  writer_ = MakeActivity(TransportWriteLoop(transport),
-                         EventEngineWakeupScheduler(event_engine),
-                         OnTransportActivityDone("writer"));
-  reader_ = MakeActivity(TransportReadLoop(std::move(transport)),
-                         EventEngineWakeupScheduler(event_engine),
-                         OnTransportActivityDone("reader"));
+  auto party_arena = SimpleArenaAllocator(0)->MakeArena();
+  party_arena->SetContext<grpc_event_engine::experimental::EventEngine>(
+      event_engine.get());
+  party_ = Party::Make(std::move(party_arena));
+  party_->Spawn("server-chaotic-writer",
+                GRPC_LATENT_SEE_PROMISE("ServerTransportWriteLoop",
+                                        TransportWriteLoop(transport)),
+                OnTransportActivityDone("writer"));
+  party_->Spawn("server-chaotic-reader",
+                GRPC_LATENT_SEE_PROMISE("ServerTransportReadLoop",
+                                        TransportReadLoop(transport)),
+                OnTransportActivityDone("reader"));
 }
 
 void ChaoticGoodServerTransport::SetCallDestination(
@@ -380,15 +399,13 @@ void ChaoticGoodServerTransport::SetCallDestination(
 }
 
 void ChaoticGoodServerTransport::Orphan() {
-  ActivityPtr writer;
-  ActivityPtr reader;
+  AbortWithError();
+  RefCountedPtr<Party> party;
   {
     MutexLock lock(&mu_);
-    writer = std::move(writer_);
-    reader = std::move(reader_);
+    party = std::move(party_);
   }
-  writer.reset();
-  reader.reset();
+  party.reset();
   Unref();
 }
 
@@ -397,6 +414,7 @@ void ChaoticGoodServerTransport::AbortWithError() {
   // Close all the available pipes.
   outgoing_frames_.MarkClosed();
   ReleasableMutexLock lock(&mu_);
+  aborted_with_error_ = true;
   StreamMap stream_map = std::move(stream_map_);
   stream_map_.clear();
   state_tracker_.SetState(GRPC_CHANNEL_SHUTDOWN,
@@ -414,6 +432,8 @@ void ChaoticGoodServerTransport::AbortWithError() {
 
 absl::optional<CallInitiator> ChaoticGoodServerTransport::LookupStream(
     uint32_t stream_id) {
+  GRPC_TRACE_LOG(chaotic_good, INFO)
+      << "CHAOTIC_GOOD " << this << " LookupStream " << stream_id;
   MutexLock lock(&mu_);
   auto it = stream_map_.find(stream_id);
   if (it == stream_map_.end()) return absl::nullopt;
@@ -422,6 +442,8 @@ absl::optional<CallInitiator> ChaoticGoodServerTransport::LookupStream(
 
 absl::optional<CallInitiator> ChaoticGoodServerTransport::ExtractStream(
     uint32_t stream_id) {
+  GRPC_TRACE_LOG(chaotic_good, INFO)
+      << "CHAOTIC_GOOD " << this << " ExtractStream " << stream_id;
   MutexLock lock(&mu_);
   auto it = stream_map_.find(stream_id);
   if (it == stream_map_.end()) return absl::nullopt;
@@ -432,7 +454,12 @@ absl::optional<CallInitiator> ChaoticGoodServerTransport::ExtractStream(
 
 absl::Status ChaoticGoodServerTransport::NewStream(
     uint32_t stream_id, CallInitiator call_initiator) {
+  GRPC_TRACE_LOG(chaotic_good, INFO)
+      << "CHAOTIC_GOOD " << this << " NewStream " << stream_id;
   MutexLock lock(&mu_);
+  if (aborted_with_error_) {
+    return absl::UnavailableError("Transport closed");
+  }
   auto it = stream_map_.find(stream_id);
   if (it != stream_map_.end()) {
     return absl::InternalError("Stream already exists");
@@ -440,16 +467,29 @@ absl::Status ChaoticGoodServerTransport::NewStream(
   if (stream_id <= last_seen_new_stream_id_) {
     return absl::InternalError("Stream id is not increasing");
   }
+  const bool on_done_added = call_initiator.OnDone(
+      [self = RefAsSubclass<ChaoticGoodServerTransport>(), stream_id](bool) {
+        GRPC_TRACE_LOG(chaotic_good, INFO)
+            << "CHAOTIC_GOOD " << self.get() << " OnDone " << stream_id;
+        absl::optional<CallInitiator> call_initiator =
+            self->ExtractStream(stream_id);
+        if (call_initiator.has_value()) {
+          auto c = std::move(*call_initiator);
+          c.SpawnInfallible("cancel", [c]() mutable {
+            c.Cancel();
+            return Empty{};
+          });
+        }
+      });
+  if (!on_done_added) {
+    return absl::CancelledError();
+  }
   stream_map_.emplace(stream_id, call_initiator);
-  call_initiator.OnDone([this, stream_id]() {
-    MutexLock lock(&mu_);
-    stream_map_.erase(stream_id);
-  });
   return absl::OkStatus();
 }
 
 void ChaoticGoodServerTransport::PerformOp(grpc_transport_op* op) {
-  std::vector<ActivityPtr> cancelled;
+  RefCountedPtr<Party> cancelled_party;
   MutexLock lock(&mu_);
   bool did_stuff = false;
   if (op->start_connectivity_watch != nullptr) {
@@ -470,8 +510,11 @@ void ChaoticGoodServerTransport::PerformOp(grpc_transport_op* op) {
     did_stuff = true;
   }
   if (!op->goaway_error.ok() || !op->disconnect_with_error.ok()) {
-    cancelled.push_back(std::move(writer_));
-    cancelled.push_back(std::move(reader_));
+    cancelled_party = std::move(party_);
+    outgoing_frames_.MarkClosed();
+    state_tracker_.SetState(GRPC_CHANNEL_SHUTDOWN,
+                            absl::UnavailableError("transport closed"),
+                            "transport closed");
     did_stuff = true;
   }
   if (!did_stuff) {
