@@ -14,11 +14,10 @@
 
 #include "src/core/ext/transport/chaotic_good/settings_metadata.h"
 
-#include "absl/status/status.h"
-
 #include <grpc/support/port_platform.h>
 
-#include "src/core/lib/gprpp/crash.h"
+#include "absl/status/status.h"
+#include "src/core/util/crash.h"
 
 namespace grpc_core {
 namespace chaotic_good {
