@@ -18,9 +18,8 @@
 
 #include "src/core/lib/security/credentials/tls/grpc_tls_crl_provider.h"
 
-#include <limits.h>
-
 #include <grpc/support/port_platform.h>
+#include <limits.h>
 
 // IWYU pragma: no_include <ratio>
 #include <memory>
@@ -41,12 +40,11 @@
 #include "absl/strings/str_cat.h"
 #include "absl/strings/str_join.h"
 #include "absl/types/span.h"
-
 #include "src/core/lib/event_engine/default_event_engine.h"
-#include "src/core/lib/gprpp/directory_reader.h"
-#include "src/core/lib/gprpp/load_file.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/slice/slice.h"
+#include "src/core/util/directory_reader.h"
+#include "src/core/util/load_file.h"
 
 namespace grpc_core {
 namespace experimental {
