@@ -16,31 +16,29 @@
 //
 //
 
+#include <grpc/support/port_platform.h>
+
 #include <algorithm>
 #include <string>
 #include <vector>
 
-#include <grpc/support/port_platform.h>
-
 #if defined(GPR_LINUX) || defined(GPR_ANDROID) || defined(GPR_FREEBSD) || \
     defined(GPR_APPLE)
 
 #include <dirent.h>
 #include <fcntl.h>
+#include <grpc/support/alloc.h>
 #include <stdio.h>
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <unistd.h>
 
 #include "absl/log/log.h"
-
-#include <grpc/support/alloc.h>
-
 #include "src/core/lib/config/config_vars.h"
-#include "src/core/lib/gprpp/load_file.h"
 #include "src/core/lib/iomgr/error.h"
 #include "src/core/lib/security/security_connector/load_system_roots.h"
 #include "src/core/lib/security/security_connector/load_system_roots_supported.h"
+#include "src/core/util/load_file.h"
 #include "src/core/util/useful.h"
 
 namespace grpc_core {
