@@ -15,12 +15,6 @@
 //
 //
 
-#include <vector>
-
-#include "absl/base/thread_annotations.h"
-#include "absl/log/check.h"
-#include "absl/log/log.h"
-
 #include <grpc/grpc.h>
 #include <grpc/support/cpu.h>
 #include <grpc/support/sync.h>
@@ -29,8 +23,13 @@
 #include <grpcpp/impl/completion_queue_tag.h>
 #include <grpcpp/impl/grpc_library.h>
 
-#include "src/core/lib/gprpp/sync.h"
-#include "src/core/lib/gprpp/thd.h"
+#include <vector>
+
+#include "absl/base/thread_annotations.h"
+#include "absl/log/check.h"
+#include "absl/log/log.h"
+#include "src/core/util/sync.h"
+#include "src/core/util/thd.h"
 #include "src/core/util/useful.h"
 
 namespace grpc {
