@@ -17,6 +17,7 @@
 #ifndef GRPC_SRC_CPP_EXT_GCP_OBSERVABILITY_CONFIG_H
 #define GRPC_SRC_CPP_EXT_GCP_OBSERVABILITY_CONFIG_H
 
+#include <grpc/support/port_platform.h>
 #include <stdint.h>
 
 #include <map>
@@ -26,13 +27,10 @@
 #include "absl/status/statusor.h"
 #include "absl/strings/string_view.h"
 #include "absl/types/optional.h"
-
-#include <grpc/support/port_platform.h>
-
-#include "src/core/lib/gprpp/validation_errors.h"
 #include "src/core/util/json/json.h"
 #include "src/core/util/json/json_args.h"
 #include "src/core/util/json/json_object_loader.h"
+#include "src/core/util/validation_errors.h"
 
 namespace grpc {
 namespace internal {
