@@ -12,18 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include <grpc/event_engine/event_engine.h>
+#include <gtest/gtest.h>
 #include <stdio.h>
 
-#include <gtest/gtest.h>
-
 #include "absl/log/check.h"
-
-#include <grpc/event_engine/event_engine.h>
-
 #include "src/core/lib/config/config_vars.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/experiments/config.h"
-#include "src/core/lib/gprpp/env.h"
+#include "src/core/util/env.h"
 #include "src/libfuzzer/libfuzzer_macro.h"
 #include "test/core/call/yodel/fuzzer.pb.h"
 #include "test/core/call/yodel/yodel_test.h"
