@@ -16,22 +16,21 @@
 
 #include "src/core/client_channel/retry_service_config.h"
 
-#include "absl/status/status.h"
-#include "absl/status/statusor.h"
-#include "gtest/gtest.h"
-
 #include <grpc/grpc.h>
 #include <grpc/impl/channel_arg_names.h>
 #include <grpc/slice.h>
 #include <grpc/status.h>
 
+#include "absl/status/status.h"
+#include "absl/status/statusor.h"
+#include "gtest/gtest.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/config/core_configuration.h"
-#include "src/core/lib/gprpp/ref_counted_ptr.h"
-#include "src/core/lib/gprpp/time.h"
 #include "src/core/service_config/service_config.h"
 #include "src/core/service_config/service_config_impl.h"
 #include "src/core/service_config/service_config_parser.h"
+#include "src/core/util/ref_counted_ptr.h"
+#include "src/core/util/time.h"
 #include "test/core/test_util/test_config.h"
 
 namespace grpc_core {
@@ -473,7 +472,7 @@ TEST_F(RetryParserTest,
       << service_config.status();
 }
 
-TEST_F(RetryParserTest, InvalidRetryPolicyUnparseableRetryableStatusCodes) {
+TEST_F(RetryParserTest, InvalidRetryPolicyUnparsableRetryableStatusCodes) {
   const char* test_json =
       "{\n"
       "  \"methodConfig\": [ {\n"
@@ -614,7 +613,7 @@ TEST_F(RetryParserTest,
   EXPECT_TRUE(parsed_config->retryable_status_codes().Empty());
 }
 
-TEST_F(RetryParserTest, InvalidRetryPolicyPerAttemptRecvTimeoutUnparseable) {
+TEST_F(RetryParserTest, InvalidRetryPolicyPerAttemptRecvTimeoutUnparsable) {
   const char* test_json =
       "{\n"
       "  \"methodConfig\": [ {\n"
