@@ -18,15 +18,6 @@
 
 #include "test/core/end2end/fuzzers/fuzzing_common.h"
 
-#include <string.h>
-
-#include <memory>
-#include <new>
-
-#include "absl/log/check.h"
-#include "absl/strings/str_cat.h"
-#include "absl/types/optional.h"
-
 #include <grpc/byte_buffer.h>
 #include <grpc/event_engine/event_engine.h>
 #include <grpc/grpc.h>
@@ -34,16 +25,24 @@
 #include <grpc/status.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/time.h>
+#include <string.h>
 
+#include <memory>
+#include <new>
+
+#include "absl/log/check.h"
+#include "absl/log/log.h"
+#include "absl/strings/str_cat.h"
+#include "absl/types/optional.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/experiments/config.h"
-#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/iomgr/executor.h"
 #include "src/core/lib/iomgr/timer_manager.h"
 #include "src/core/lib/resource_quota/memory_quota.h"
 #include "src/core/lib/slice/slice_internal.h"
 #include "src/core/lib/surface/channel.h"
+#include "src/core/util/crash.h"
 #include "test/core/end2end/fuzzers/api_fuzzer.pb.h"
 
 namespace grpc_core {
@@ -638,7 +637,7 @@ bool BasicFuzzer::Continue() {
 
 BasicFuzzer::Result BasicFuzzer::ExecuteAction(
     const api_fuzzer::Action& action) {
-  gpr_log(GPR_DEBUG, "EXECUTE_ACTION: %s", action.DebugString().c_str());
+  VLOG(2) << "EXECUTE_ACTION: " << action.DebugString();
   switch (action.type_case()) {
     case api_fuzzer::Action::TYPE_NOT_SET:
       return BasicFuzzer::Result::kFailed;
