@@ -27,9 +27,8 @@
 #include "absl/log/check.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
-
 #include "src/core/lib/event_engine/posix_engine/timer.h"
-#include "src/core/lib/gprpp/bitset.h"
+#include "src/core/util/bitset.h"
 
 using testing::Contains;
 using testing::Not;
