@@ -15,6 +15,9 @@
 // IWYU pragma: no_include <ratio>
 // IWYU pragma: no_include <arpa/inet.h>
 
+#include <grpc/event_engine/event_engine.h>
+#include <grpc/support/port_platform.h>
+
 #include <cstdlib>
 #include <cstring>
 #include <memory>
@@ -31,15 +34,11 @@
 #include "absl/types/optional.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
-
-#include <grpc/event_engine/event_engine.h>
-#include <grpc/support/port_platform.h>
-
 #include "src/core/lib/config/config_vars.h"
 #include "src/core/lib/event_engine/tcp_socket_utils.h"
-#include "src/core/lib/gprpp/crash.h"  // IWYU pragma: keep
-#include "src/core/lib/gprpp/notification.h"
 #include "src/core/lib/iomgr/sockaddr.h"
+#include "src/core/util/crash.h"  // IWYU pragma: keep
+#include "src/core/util/notification.h"
 #include "test/core/event_engine/test_suite/event_engine_test_framework.h"
 #include "test/core/test_util/fake_udp_and_tcp_server.h"
 #include "test/core/test_util/port.h"
@@ -557,7 +556,7 @@ TEST_F(EventEngineDNSTest, InvalidIPv6Addresses) {
                        &dns_resolver_signal_, "[2001:db8::11111]:1");
 }
 
-void TestUnparseableHostPort(
+void TestUnparsableHostPort(
     std::unique_ptr<EventEngine::DNSResolver> dns_resolver,
     grpc_core::Notification* barrier, absl::string_view target) {
   dns_resolver->LookupHostname(
@@ -569,38 +568,38 @@ void TestUnparseableHostPort(
   barrier->WaitForNotification();
 }
 
-TEST_F(EventEngineDNSTest, UnparseableHostPortsOnlyBracket) {
-  TestUnparseableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
-                          &dns_resolver_signal_, "[");
+TEST_F(EventEngineDNSTest, UnparsableHostPortsOnlyBracket) {
+  TestUnparsableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
+                         &dns_resolver_signal_, "[");
 }
 
-TEST_F(EventEngineDNSTest, UnparseableHostPortsMissingRightBracket) {
-  TestUnparseableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
-                          &dns_resolver_signal_, "[::1");
+TEST_F(EventEngineDNSTest, UnparsableHostPortsMissingRightBracket) {
+  TestUnparsableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
+                         &dns_resolver_signal_, "[::1");
 }
 
-TEST_F(EventEngineDNSTest, UnparseableHostPortsBadPort) {
-  TestUnparseableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
-                          &dns_resolver_signal_, "[::1]bad");
+TEST_F(EventEngineDNSTest, UnparsableHostPortsBadPort) {
+  TestUnparsableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
+                         &dns_resolver_signal_, "[::1]bad");
 }
 
-TEST_F(EventEngineDNSTest, UnparseableHostPortsBadIPv6) {
-  TestUnparseableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
-                          &dns_resolver_signal_, "[1.2.3.4]");
+TEST_F(EventEngineDNSTest, UnparsableHostPortsBadIPv6) {
+  TestUnparsableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
+                         &dns_resolver_signal_, "[1.2.3.4]");
 }
 
-TEST_F(EventEngineDNSTest, UnparseableHostPortsBadLocalhost) {
-  TestUnparseableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
-                          &dns_resolver_signal_, "[localhost]");
+TEST_F(EventEngineDNSTest, UnparsableHostPortsBadLocalhost) {
+  TestUnparsableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
+                         &dns_resolver_signal_, "[localhost]");
 }
 
-TEST_F(EventEngineDNSTest, UnparseableHostPortsBadLocalhostWithPort) {
-  TestUnparseableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
-                          &dns_resolver_signal_, "[localhost]:1");
+TEST_F(EventEngineDNSTest, UnparsableHostPortsBadLocalhostWithPort) {
+  TestUnparsableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
+                         &dns_resolver_signal_, "[localhost]:1");
 }
 
-TEST_F(EventEngineDNSTest, UnparseableHostPortsEmptyHostname) {
-  TestUnparseableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
-                          &dns_resolver_signal_, ":443");
+TEST_F(EventEngineDNSTest, UnparsableHostPortsEmptyHostname) {
+  TestUnparsableHostPort(CreateDNSResolverWithoutSpecifyingServer(),
+                         &dns_resolver_signal_, ":443");
 }
 // END
