@@ -11,13 +11,12 @@
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
+#include <grpc/event_engine/slice.h>
+#include <grpc/support/port_platform.h>
 #include <stdlib.h>
 
 #include "absl/log/check.h"
 
-#include <grpc/event_engine/slice.h>
-#include <grpc/support/port_platform.h>
-
 // The echo client wraps an EventEngine::Connect and EventEngine::Endpoint
 // implementations, allowing third-party TCP listeners to interact with your
 // EventEngine client. Example usage:
@@ -31,6 +30,10 @@
 //    bazel run
 //    //test/core/event_engine/test_suite/tools:my_event_engine_echo_client
 
+#include <grpc/event_engine/event_engine.h>
+#include <grpc/event_engine/slice_buffer.h>
+#include <grpc/grpc.h>
+
 #include <chrono>
 #include <memory>
 #include <string>
@@ -43,19 +46,14 @@
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/str_format.h"
-
-#include <grpc/event_engine/event_engine.h>
-#include <grpc/event_engine/slice_buffer.h>
-#include <grpc/grpc.h>
-
 #include "src/core/lib/channel/channel_args_preconditioning.h"
 #include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/event_engine/channel_args_endpoint_config.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/event_engine/tcp_socket_utils.h"
-#include "src/core/lib/gprpp/notification.h"
 #include "src/core/lib/resource_quota/memory_quota.h"
 #include "src/core/resolver/resolver_registry.h"
+#include "src/core/util/notification.h"
 
 extern absl::AnyInvocable<
     std::unique_ptr<grpc_event_engine::experimental::EventEngine>(void)>
