@@ -18,31 +18,28 @@
 
 #include "src/core/lib/iomgr/resolve_address.h"
 
-#include <string.h>
-
 #include <address_sorting/address_sorting.h>
 #include <gmock/gmock.h>
+#include <grpc/grpc.h>
+#include <grpc/support/alloc.h>
+#include <grpc/support/sync.h>
+#include <grpc/support/time.h>
 #include <gtest/gtest.h>
+#include <string.h>
 
 #include "absl/functional/bind_front.h"
 #include "absl/log/check.h"
+#include "absl/log/log.h"
 #include "absl/strings/match.h"
-
-#include <grpc/grpc.h>
-#include <grpc/support/alloc.h>
-#include <grpc/support/log.h>
-#include <grpc/support/sync.h>
-#include <grpc/support/time.h>
-
 #include "src/core/lib/config/config_vars.h"
-#include "src/core/lib/gpr/string.h"
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/sync.h"
-#include "src/core/lib/gprpp/time.h"
 #include "src/core/lib/iomgr/executor.h"
 #include "src/core/lib/iomgr/iomgr.h"
 #include "src/core/lib/iomgr/pollset.h"
 #include "src/core/resolver/dns/c_ares/grpc_ares_wrapper.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/string.h"
+#include "src/core/util/sync.h"
+#include "src/core/util/time.h"
 #include "test/core/test_util/cmdline.h"
 #include "test/core/test_util/fake_udp_and_tcp_server.h"
 #include "test/core/test_util/test_config.h"
@@ -102,8 +99,7 @@ class ResolveAddressTest : public ::testing::Test {
           break;
         }
         grpc_core::Duration time_left = deadline - grpc_core::Timestamp::Now();
-        gpr_log(GPR_DEBUG, "done=%d, time_left=%" PRId64, done_,
-                time_left.millis());
+        VLOG(2) << "done=" << done_ << ", time_left=" << time_left.millis();
         ASSERT_GE(time_left, grpc_core::Duration::Zero());
         grpc_pollset_worker* worker = nullptr;
         GRPC_LOG_IF_ERROR("pollset_work", grpc_pollset_work(pollset_, &worker,
@@ -241,7 +237,7 @@ const address_sorting_source_addr_factory_vtable
 
 }  // namespace
 
-TEST_F(ResolveAddressTest, LocalhostResultHasIPv4FirstWhenIPv6IsntAvalailable) {
+TEST_F(ResolveAddressTest, LocalhostResultHasIPv4FirstWhenIPv6IsntAvailable) {
   if (std::string(g_resolver_type) != "ares") {
     GTEST_SKIP() << "this test is only valid with the c-ares resolver";
   }
@@ -327,7 +323,7 @@ TEST_F(ResolveAddressTest, InvalidIPv6Addresses) {
   TestInvalidIPAddress(this, "[2001:db8::11111]:1");
 }
 
-void TestUnparseableHostPort(ResolveAddressTest* test, const char* target) {
+void TestUnparsableHostPort(ResolveAddressTest* test, const char* target) {
   grpc_core::ExecCtx exec_ctx;
   grpc_core::GetDNSResolver()->LookupHostname(
       absl::bind_front(&ResolveAddressTest::MustFail, test), target, "1",
@@ -336,28 +332,28 @@ void TestUnparseableHostPort(ResolveAddressTest* test, const char* target) {
   test->PollPollsetUntilRequestDone();
 }
 
-TEST_F(ResolveAddressTest, UnparseableHostPortsOnlyBracket) {
-  TestUnparseableHostPort(this, "[");
+TEST_F(ResolveAddressTest, UnparsableHostPortsOnlyBracket) {
+  TestUnparsableHostPort(this, "[");
 }
 
-TEST_F(ResolveAddressTest, UnparseableHostPortsMissingRightBracket) {
-  TestUnparseableHostPort(this, "[::1");
+TEST_F(ResolveAddressTest, UnparsableHostPortsMissingRightBracket) {
+  TestUnparsableHostPort(this, "[::1");
 }
 
-TEST_F(ResolveAddressTest, UnparseableHostPortsBadPort) {
-  TestUnparseableHostPort(this, "[::1]bad");
+TEST_F(ResolveAddressTest, UnparsableHostPortsBadPort) {
+  TestUnparsableHostPort(this, "[::1]bad");
 }
 
-TEST_F(ResolveAddressTest, UnparseableHostPortsBadIPv6) {
-  TestUnparseableHostPort(this, "[1.2.3.4]");
+TEST_F(ResolveAddressTest, UnparsableHostPortsBadIPv6) {
+  TestUnparsableHostPort(this, "[1.2.3.4]");
 }
 
-TEST_F(ResolveAddressTest, UnparseableHostPortsBadLocalhost) {
-  TestUnparseableHostPort(this, "[localhost]");
+TEST_F(ResolveAddressTest, UnparsableHostPortsBadLocalhost) {
+  TestUnparsableHostPort(this, "[localhost]");
 }
 
-TEST_F(ResolveAddressTest, UnparseableHostPortsBadLocalhostWithPort) {
-  TestUnparseableHostPort(this, "[localhost]:1");
+TEST_F(ResolveAddressTest, UnparsableHostPortsBadLocalhostWithPort) {
+  TestUnparsableHostPort(this, "[localhost]:1");
 }
 
 // Kick off a simple DNS resolution and then immediately cancel. This
@@ -392,9 +388,8 @@ namespace {
 int g_fake_non_responsive_dns_server_port;
 
 void InjectNonResponsiveDNSServer(ares_channel* channel) {
-  gpr_log(GPR_DEBUG,
-          "Injecting broken nameserver list. Bad server address:|[::1]:%d|.",
-          g_fake_non_responsive_dns_server_port);
+  VLOG(2) << "Injecting broken nameserver list. Bad server address:|[::1]:"
+          << g_fake_non_responsive_dns_server_port << "|.";
   // Configure a non-responsive DNS server at the front of c-ares's nameserver
   // list.
   struct ares_addr_port_node dns_server_addrs[1];
@@ -450,7 +445,7 @@ class PollsetSetWrapper {
     grpc_core::ExecCtx::Get()->Flush();
     grpc_pollset_destroy(ps_);
     gpr_free(ps_);
-    gpr_log(GPR_DEBUG, "PollsetSetWrapper:%p deleted", this);
+    VLOG(2) << "PollsetSetWrapper:" << this << " deleted";
   }
 
   grpc_pollset_set* pollset_set() { return pss_; }
@@ -461,7 +456,7 @@ class PollsetSetWrapper {
     grpc_pollset_init(ps_, &mu_);
     pss_ = grpc_pollset_set_create();
     grpc_pollset_set_add_pollset(pss_, ps_);
-    gpr_log(GPR_DEBUG, "PollsetSetWrapper:%p created", this);
+    VLOG(2) << "PollsetSetWrapper:" << this << " created";
   }
 
   gpr_mu* mu_;
