@@ -17,6 +17,10 @@
 #ifndef GRPC_TEST_CORE_LOAD_BALANCING_LB_POLICY_TEST_LIB_H
 #define GRPC_TEST_CORE_LOAD_BALANCING_LB_POLICY_TEST_LIB_H
 
+#include <grpc/event_engine/event_engine.h>
+#include <grpc/grpc.h>
+#include <grpc/support/alloc.h>
+#include <grpc/support/port_platform.h>
 #include <inttypes.h>
 #include <stddef.h>
 
@@ -36,6 +40,7 @@
 #include "absl/base/thread_annotations.h"
 #include "absl/functional/any_invocable.h"
 #include "absl/log/check.h"
+#include "absl/log/log.h"
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/str_format.h"
@@ -47,13 +52,6 @@
 #include "absl/types/variant.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
-
-#include <grpc/event_engine/event_engine.h>
-#include <grpc/grpc.h>
-#include <grpc/support/alloc.h>
-#include <grpc/support/log.h>
-#include <grpc/support/port_platform.h>
-
 #include "src/core/client_channel/client_channel_internal.h"
 #include "src/core/client_channel/subchannel_interface_internal.h"
 #include "src/core/client_channel/subchannel_pool_interface.h"
@@ -62,20 +60,10 @@
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
-#include "src/core/lib/gprpp/debug_location.h"
-#include "src/core/lib/gprpp/match.h"
-#include "src/core/lib/gprpp/orphanable.h"
-#include "src/core/lib/gprpp/ref_counted_ptr.h"
-#include "src/core/lib/gprpp/sync.h"
-#include "src/core/lib/gprpp/time.h"
-#include "src/core/lib/gprpp/unique_type_name.h"
-#include "src/core/lib/gprpp/work_serializer.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/iomgr/resolved_address.h"
-#include "src/core/lib/json/json.h"
 #include "src/core/lib/security/credentials/credentials.h"
 #include "src/core/lib/transport/connectivity_state.h"
-#include "src/core/lib/uri/uri_parser.h"
 #include "src/core/load_balancing/backend_metric_data.h"
 #include "src/core/load_balancing/health_check_client_internal.h"
 #include "src/core/load_balancing/lb_policy.h"
@@ -85,6 +73,16 @@
 #include "src/core/load_balancing/subchannel_interface.h"
 #include "src/core/resolver/endpoint_addresses.h"
 #include "src/core/service_config/service_config_call_data.h"
+#include "src/core/util/debug_location.h"
+#include "src/core/util/json/json.h"
+#include "src/core/util/match.h"
+#include "src/core/util/orphanable.h"
+#include "src/core/util/ref_counted_ptr.h"
+#include "src/core/util/sync.h"
+#include "src/core/util/time.h"
+#include "src/core/util/unique_type_name.h"
+#include "src/core/util/uri.h"
+#include "src/core/util/work_serializer.h"
 #include "test/core/event_engine/event_engine_test_utils.h"
 #include "test/core/event_engine/fuzzing_event_engine/fuzzing_event_engine.h"
 #include "test/core/event_engine/fuzzing_event_engine/fuzzing_event_engine.pb.h"
@@ -121,6 +119,8 @@ class LoadBalancingPolicyTest : public ::testing::Test {
 
       SubchannelState* state() const { return state_; }
 
+      std::string address() const override { return state_->address_; }
+
      private:
       // Converts between
       // SubchannelInterface::ConnectivityStateWatcherInterface and
@@ -152,8 +152,8 @@ class LoadBalancingPolicyTest : public ::testing::Test {
 
         void OnConnectivityStateChange(grpc_connectivity_state new_state,
                                        const absl::Status& status) override {
-          gpr_log(GPR_INFO, "notifying watcher: state=%s status=%s",
-                  ConnectivityStateName(new_state), status.ToString().c_str());
+          LOG(INFO) << "notifying watcher: state="
+                    << ConnectivityStateName(new_state) << " status=" << status;
           watcher_->OnConnectivityStateChange(new_state, status);
         }
 
@@ -212,11 +212,10 @@ class LoadBalancingPolicyTest : public ::testing::Test {
           health_watcher_wrapper_ = watcher_wrapper.get();
           state_->state_tracker_.AddWatcher(GRPC_CHANNEL_SHUTDOWN,
                                             std::move(watcher_wrapper));
-          gpr_log(GPR_INFO,
-                  "AddDataWatcher(): added HealthWatch=%p "
-                  "connectivity_watcher=%p watcher_wrapper=%p",
-                  health_watcher_.get(), connectivity_watcher_ptr,
-                  health_watcher_wrapper_);
+          LOG(INFO) << "AddDataWatcher(): added HealthWatch="
+                    << health_watcher_.get()
+                    << " connectivity_watcher=" << connectivity_watcher_ptr
+                    << " watcher_wrapper=" << health_watcher_wrapper_;
         }
       }
 
@@ -232,10 +231,9 @@ class LoadBalancingPolicyTest : public ::testing::Test {
           if (health_watcher_.get() != static_cast<HealthWatcher*>(watcher)) {
             return;
           }
-          gpr_log(GPR_INFO,
-                  "CancelDataWatcher(): cancelling HealthWatch=%p "
-                  "watcher_wrapper=%p",
-                  health_watcher_.get(), health_watcher_wrapper_);
+          LOG(INFO) << "CancelDataWatcher(): cancelling HealthWatch="
+                    << health_watcher_.get()
+                    << " watcher_wrapper=" << health_watcher_wrapper_;
           state_->state_tracker_.RemoveWatcher(health_watcher_wrapper_);
           health_watcher_wrapper_ = nullptr;
           health_watcher_.reset();
@@ -327,18 +325,16 @@ class LoadBalancingPolicyTest : public ::testing::Test {
               AssertValidConnectivityStateTransition(state_tracker_.state(),
                                                      state, location);
             }
-            gpr_log(GPR_INFO, "Setting state on tracker");
+            LOG(INFO) << "Setting state on tracker";
             state_tracker_.SetState(state, status, "set from test");
             // SetState() enqueued the connectivity state notifications for
             // the subchannel, so we add another callback to the queue to be
             // executed after that state notifications has been delivered.
-            gpr_log(GPR_INFO,
-                    "Waiting for state notifications to be delivered");
+            LOG(INFO) << "Waiting for state notifications to be delivered";
             test_->work_serializer_->Run(
                 [&]() {
-                  gpr_log(GPR_INFO,
-                          "State notifications delivered, waiting for health "
-                          "notifications");
+                  LOG(INFO) << "State notifications delivered, waiting for "
+                               "health notifications";
                   // Now the connectivity state notifications has been
                   // delivered. If the state reported was READY, then the
                   // pick_first leaf policy will have started a health watch, so
@@ -351,7 +347,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
           },
           DEBUG_LOCATION);
       notification.WaitForNotification();
-      gpr_log(GPR_INFO, "Health notifications delivered");
+      LOG(INFO) << "Health notifications delivered";
     }
 
     // Indicates if any of the associated SubchannelInterface objects
@@ -472,8 +468,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
           << location.file() << ":" << location.line();
       if (update == nullptr) return absl::nullopt;
       StateUpdate result = std::move(*update);
-      gpr_log(GPR_INFO, "dequeued next state update: %s",
-              result.ToString().c_str());
+      LOG(INFO) << "dequeued next state update: " << result.ToString();
       queue_.pop_front();
       return std::move(result);
     }
@@ -506,8 +501,8 @@ class LoadBalancingPolicyTest : public ::testing::Test {
       PickerWrapper(LoadBalancingPolicyTest* test,
                     RefCountedPtr<LoadBalancingPolicy::SubchannelPicker> picker)
           : test_(test), picker_(std::move(picker)) {
-        gpr_log(GPR_INFO, "creating wrapper %p for picker %p", this,
-                picker_.get());
+        LOG(INFO) << "creating wrapper " << this << " for picker "
+                  << picker_.get();
       }
 
       void Orphaned() override {
@@ -579,8 +574,8 @@ class LoadBalancingPolicyTest : public ::testing::Test {
       StateUpdate update{
           state, status,
           MakeRefCounted<PickerWrapper>(test_, std::move(picker))};
-      gpr_log(GPR_INFO, "enqueuing state update from LB policy: %s",
-              update.ToString().c_str());
+      LOG(INFO) << "enqueuing state update from LB policy: "
+                << update.ToString();
       queue_.push_back(std::move(update));
     }
 
@@ -625,20 +620,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
     explicit FakeMetadata(std::map<std::string, std::string> metadata)
         : metadata_(std::move(metadata)) {}
 
-    const std::map<std::string, std::string>& metadata() const {
-      return metadata_;
-    }
-
    private:
-    void Add(absl::string_view key, absl::string_view value) override {
-      metadata_[std::string(key)] = std::string(value);
-    }
-
-    std::vector<std::pair<std::string, std::string>> TestOnlyCopyToVector()
-        override {
-      return {};  // Not used.
-    }
-
     absl::optional<absl::string_view> Lookup(
         absl::string_view key, std::string* /*buffer*/) const override {
       auto it = metadata_.find(std::string(key));
@@ -847,14 +829,12 @@ class LoadBalancingPolicyTest : public ::testing::Test {
           // notifications for the subchannels, so we add another
           // callback to the queue to be executed after those initial
           // state notifications have been delivered.
-          gpr_log(GPR_INFO,
-                  "Applied update, waiting for initial connectivity state "
-                  "notifications");
+          LOG(INFO) << "Applied update, waiting for initial connectivity state "
+                       "notifications";
           work_serializer_->Run(
               [&]() {
-                gpr_log(GPR_INFO,
-                        "Initial connectivity state notifications delivered; "
-                        "waiting for health notifications");
+                LOG(INFO) << "Initial connectivity state notifications "
+                             "delivered; waiting for health notifications";
                 // Now that the initial state notifications have been
                 // delivered, the queue will contain the health watch
                 // notifications for any subchannels in state READY,
@@ -868,7 +848,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
         },
         DEBUG_LOCATION);
     notification.WaitForNotification();
-    gpr_log(GPR_INFO, "health notifications delivered");
+    LOG(INFO) << "health notifications delivered";
     return status;
   }
 
@@ -900,15 +880,15 @@ class LoadBalancingPolicyTest : public ::testing::Test {
   bool WaitForStateUpdate(
       std::function<bool(FakeHelper::StateUpdate update)> continue_predicate,
       SourceLocation location = SourceLocation()) {
-    gpr_log(GPR_INFO, "==> WaitForStateUpdate()");
+    LOG(INFO) << "==> WaitForStateUpdate()";
     while (true) {
       auto update = helper_->GetNextStateUpdate(location);
       if (!update.has_value()) {
-        gpr_log(GPR_INFO, "WaitForStateUpdate() returning false");
+        LOG(INFO) << "WaitForStateUpdate() returning false";
         return false;
       }
       if (!continue_predicate(std::move(*update))) {
-        gpr_log(GPR_INFO, "WaitForStateUpdate() returning true");
+        LOG(INFO) << "WaitForStateUpdate() returning true";
         return true;
       }
     }
@@ -945,7 +925,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
   // update for state READY, whose picker is returned.
   RefCountedPtr<LoadBalancingPolicy::SubchannelPicker> WaitForConnected(
       SourceLocation location = SourceLocation()) {
-    gpr_log(GPR_INFO, "==> WaitForConnected()");
+    LOG(INFO) << "==> WaitForConnected()";
     RefCountedPtr<LoadBalancingPolicy::SubchannelPicker> final_picker;
     WaitForStateUpdate(
         [&](FakeHelper::StateUpdate update) {
@@ -1022,7 +1002,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
                               const CallAttributes& call_attributes = {},
                               size_t num_iterations = 3,
                               SourceLocation location = SourceLocation()) {
-    gpr_log(GPR_INFO, "Waiting for expected RR addresses...");
+    LOG(INFO) << "Waiting for expected RR addresses...";
     RefCountedPtr<LoadBalancingPolicy::SubchannelPicker> retval;
     size_t num_picks =
         std::max(new_addresses.size(), old_addresses.size()) * num_iterations;
@@ -1038,7 +1018,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
           EXPECT_TRUE(picks.has_value())
               << location.file() << ":" << location.line();
           if (!picks.has_value()) return false;
-          gpr_log(GPR_INFO, "PICKS: %s", absl::StrJoin(*picks, " ").c_str());
+          LOG(INFO) << "PICKS: " << absl::StrJoin(*picks, " ");
           // If the picks still match the old list, then keep going.
           if (PicksAreRoundRobin(old_addresses, *picks)) return true;
           // Otherwise, the picks should match the new list.
@@ -1053,7 +1033,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
           return false;  // Stop.
         },
         location);
-    gpr_log(GPR_INFO, "done waiting for expected RR addresses");
+    LOG(INFO) << "done waiting for expected RR addresses";
     return retval;
   }
 
@@ -1307,7 +1287,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
   RefCountedPtr<LoadBalancingPolicy::SubchannelPicker>
   DrainRoundRobinPickerUpdates(absl::Span<const absl::string_view> addresses,
                                SourceLocation location = SourceLocation()) {
-    gpr_log(GPR_INFO, "Draining RR picker updates...");
+    LOG(INFO) << "Draining RR picker updates...";
     RefCountedPtr<LoadBalancingPolicy::SubchannelPicker> picker;
     while (!helper_->QueueEmpty()) {
       auto update = helper_->GetNextStateUpdate(location);
@@ -1322,17 +1302,17 @@ class LoadBalancingPolicyTest : public ::testing::Test {
                             location);
       picker = std::move(update->picker);
     }
-    gpr_log(GPR_INFO, "Done draining RR picker updates");
+    LOG(INFO) << "Done draining RR picker updates";
     return picker;
   }
 
   // Expects zero or more CONNECTING updates.
   void DrainConnectingUpdates(SourceLocation location = SourceLocation()) {
-    gpr_log(GPR_INFO, "Draining CONNECTING updates...");
+    LOG(INFO) << "Draining CONNECTING updates...";
     while (!helper_->QueueEmpty()) {
       ASSERT_TRUE(ExpectConnectingUpdate(location));
     }
-    gpr_log(GPR_INFO, "Done draining CONNECTING updates");
+    LOG(INFO) << "Done draining CONNECTING updates";
   }
 
   // Triggers a connection failure for the current address for an
@@ -1341,10 +1321,10 @@ class LoadBalancingPolicyTest : public ::testing::Test {
       absl::Span<const absl::string_view> addresses, size_t current_index,
       size_t new_index, absl::AnyInvocable<void()> expect_after_disconnect,
       SourceLocation location = SourceLocation()) {
-    gpr_log(GPR_INFO,
-            "Expecting endpoint address change: addresses={%s}, "
-            "current_index=%" PRIuPTR ", new_index=%" PRIuPTR,
-            absl::StrJoin(addresses, ", ").c_str(), current_index, new_index);
+    LOG(INFO) << "Expecting endpoint address change: addresses={"
+              << absl::StrJoin(addresses, ", ")
+              << "}, current_index=" << current_index
+              << ", new_index=" << new_index;
     ASSERT_LT(current_index, addresses.size());
     ASSERT_LT(new_index, addresses.size());
     // Find all subchannels.
@@ -1385,7 +1365,7 @@ class LoadBalancingPolicyTest : public ::testing::Test {
       // interacts with it again.
       subchannel->SetConnectivityState(GRPC_CHANNEL_IDLE);
     }
-    gpr_log(GPR_INFO, "Done with endpoint address change");
+    LOG(INFO) << "Done with endpoint address change";
   }
 
   // Requests a picker on picker and expects a Fail result.
@@ -1451,19 +1431,18 @@ class LoadBalancingPolicyTest : public ::testing::Test {
 
   void WaitForWorkSerializerToFlush() {
     ExecCtx exec_ctx;
-    gpr_log(GPR_INFO, "waiting for WorkSerializer to flush...");
+    LOG(INFO) << "waiting for WorkSerializer to flush...";
     absl::Notification notification;
     work_serializer_->Run([&]() { notification.Notify(); }, DEBUG_LOCATION);
     notification.WaitForNotification();
-    gpr_log(GPR_INFO, "WorkSerializer flush complete");
+    LOG(INFO) << "WorkSerializer flush complete";
   }
 
   void IncrementTimeBy(Duration duration) {
     ExecCtx exec_ctx;
-    gpr_log(GPR_INFO, "Incrementing time by %s...",
-            duration.ToString().c_str());
+    LOG(INFO) << "Incrementing time by " << duration;
     fuzzing_ee_->TickForDuration(duration);
-    gpr_log(GPR_INFO, "Done incrementing time");
+    LOG(INFO) << "Done incrementing time";
     // Flush WorkSerializer, in case the timer callback enqueued anything.
     WaitForWorkSerializerToFlush();
   }
