@@ -16,14 +16,12 @@
 //
 //
 
+#include <grpc/grpc.h>
 #include <stdbool.h>
 
 #include "absl/log/check.h"
-
-#include <grpc/grpc.h>
-
-#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
+#include "src/core/util/crash.h"
 #include "test/core/test_util/tls_utils.h"
 
 extern "C" int LLVMFuzzerTestOneInput(const uint8_t* data, size_t size);
