@@ -18,16 +18,15 @@
 #include <memory>
 
 #include "benchmark/benchmark.h"
-
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/event_engine/event_engine_context.h"
-#include "src/core/lib/gprpp/notification.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/promise/all_ok.h"
 #include "src/core/lib/promise/map.h"
 #include "src/core/lib/resource_quota/resource_quota.h"
 #include "src/core/lib/transport/call_spine.h"
 #include "src/core/lib/transport/transport.h"
+#include "src/core/util/notification.h"
 
 namespace grpc_core {
 
@@ -56,9 +55,7 @@ void BM_UnaryWithSpawnPerEnd(benchmark::State& state) {
                       return md.status();
                     }),
                 Map(handler.PullMessage(),
-                    [](ValueOrFailure<absl::optional<MessageHandle>> msg) {
-                      return msg.status();
-                    }),
+                    [](ClientToServerNextMessage msg) { return msg.status(); }),
                 handler.PushMessage(fixture.MakePayload())),
             [&handler_done, &fixture, handler](StatusFlag status) mutable {
               CHECK(status.ok());
@@ -68,29 +65,27 @@ void BM_UnaryWithSpawnPerEnd(benchmark::State& state) {
               return Empty{};
             });
       });
-      call.initiator.SpawnInfallible(
-          "initiator",
-          [initiator = call.initiator, &fixture, &initiator_done]() mutable {
-            return Map(
-                AllOk<StatusFlag>(
-                    Map(initiator.PushMessage(fixture.MakePayload()),
-                        [](StatusFlag) { return Success{}; }),
-                    Map(initiator.PullServerInitialMetadata(),
-                        [](absl::optional<ServerMetadataHandle> md) {
-                          return Success{};
-                        }),
-                    Map(initiator.PullMessage(),
-                        [](ValueOrFailure<absl::optional<MessageHandle>> msg) {
-                          return msg.status();
-                        }),
-                    Map(initiator.PullServerTrailingMetadata(),
-                        [](ServerMetadataHandle) { return Success(); })),
-                [&initiator_done](StatusFlag result) {
-                  CHECK(result.ok());
-                  initiator_done.Notify();
-                  return Empty{};
-                });
-          });
+      call.initiator.SpawnInfallible("initiator", [initiator = call.initiator,
+                                                   &fixture,
+                                                   &initiator_done]() mutable {
+        return Map(
+            AllOk<StatusFlag>(
+                Map(initiator.PushMessage(fixture.MakePayload()),
+                    [](StatusFlag) { return Success{}; }),
+                Map(initiator.PullServerInitialMetadata(),
+                    [](absl::optional<ServerMetadataHandle> md) {
+                      return Success{};
+                    }),
+                Map(initiator.PullMessage(),
+                    [](ServerToClientNextMessage msg) { return msg.status(); }),
+                Map(initiator.PullServerTrailingMetadata(),
+                    [](ServerMetadataHandle) { return Success(); })),
+            [&initiator_done](StatusFlag result) {
+              CHECK(result.ok());
+              initiator_done.Notify();
+              return Empty{};
+            });
+      });
     }
     handler_done.WaitForNotification();
     initiator_done.WaitForNotification();
@@ -128,7 +123,7 @@ void BM_UnaryWithSpawnPerOp(benchmark::State& state) {
           [](ValueOrFailure<ClientMetadataHandle> md) { CHECK(md.ok()); });
       handler_spawner.Spawn(
           "HANDLER:PullMessage", [&]() { return call.handler.PullMessage(); },
-          [&](ValueOrFailure<absl::optional<MessageHandle>> msg) {
+          [&](ClientToServerNextMessage msg) {
             CHECK(msg.ok());
             call.handler.SpawnInfallible(
                 "HANDLER:PushServerTrailingMetadata", [&]() {
@@ -156,9 +151,7 @@ void BM_UnaryWithSpawnPerOp(benchmark::State& state) {
       initiator_spawner.Spawn(
           "INITIATOR:PullMessage",
           [&]() { return call.initiator.PullMessage(); },
-          [](ValueOrFailure<absl::optional<MessageHandle>> msg) {
-            CHECK(msg.ok());
-          });
+          [](ServerToClientNextMessage msg) { CHECK(msg.ok()); });
       initiator_spawner.Spawn(
           "INITIATOR:PullServerTrailingMetadata",
           [&]() { return call.initiator.PullServerTrailingMetadata(); },
@@ -203,7 +196,7 @@ void BM_ClientToServerStreaming(benchmark::State& state) {
     Notification initiator_done;
     call.handler.SpawnInfallible("handler", [&]() {
       return Map(call.handler.PullMessage(),
-                 [&](ValueOrFailure<absl::optional<MessageHandle>> msg) {
+                 [&](ClientToServerNextMessage msg) {
                    CHECK(msg.ok());
                    handler_done.Notify();
                    return Empty{};
