@@ -18,10 +18,8 @@
 
 #include "test/core/tsi/transport_security_test_lib.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
+#include <grpc/grpc.h>
+#include <grpc/support/alloc.h>
 #include <openssl/asn1.h>
 #include <openssl/bio.h>
 #include <openssl/bn.h>
@@ -30,16 +28,15 @@
 #include <openssl/rsa.h>
 #include <openssl/x509.h>
 #include <openssl/x509v3.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include "absl/log/check.h"
 #include "absl/strings/str_cat.h"
-
-#include <grpc/grpc.h>
-#include <grpc/support/alloc.h>
-
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/memory.h"
 #include "src/core/lib/iomgr/error.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/memory.h"
 
 static void notification_signal(tsi_test_fixture* fixture) {
   gpr_mu_lock(&fixture->mu);
