@@ -16,6 +16,10 @@
 
 #include "src/core/xds/xds_client/xds_bootstrap.h"
 
+#include <grpc/grpc.h>
+#include <grpc/grpc_security.h>
+#include <grpc/grpc_security_constants.h>
+#include <grpc/support/alloc.h>
 #include <stdio.h>
 
 #include <map>
@@ -29,28 +33,20 @@
 #include "absl/strings/string_view.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
-
-#include <grpc/grpc.h>
-#include <grpc/grpc_security.h>
-#include <grpc/grpc_security_constants.h>
-#include <grpc/support/alloc.h>
-
 #include "src/core/lib/config/core_configuration.h"
-#include "src/core/lib/gprpp/env.h"
-#include "src/core/lib/gprpp/ref_counted_ptr.h"
-#include "src/core/lib/gprpp/validation_errors.h"
 #include "src/core/lib/security/certificate_provider/certificate_provider_factory.h"
 #include "src/core/lib/security/credentials/channel_creds_registry.h"
-#include "src/core/lib/security/credentials/tls/grpc_tls_certificate_provider.h"
+#include "src/core/util/env.h"
 #include "src/core/util/json/json.h"
 #include "src/core/util/json/json_args.h"
 #include "src/core/util/json/json_object_loader.h"
 #include "src/core/util/json/json_reader.h"
+#include "src/core/util/ref_counted_ptr.h"
 #include "src/core/util/tmpfile.h"
+#include "src/core/util/validation_errors.h"
 #include "src/core/xds/grpc/certificate_provider_store.h"
 #include "src/core/xds/grpc/xds_bootstrap_grpc.h"
 #include "src/core/xds/grpc/xds_server_grpc.h"
-#include "test/core/test_util/scoped_env_var.h"
 #include "test/core/test_util/test_config.h"
 
 namespace grpc_core {
@@ -94,16 +90,6 @@ TEST(XdsBootstrapTest, Basic) {
       "        }"
       "      ],"
       "      \"ignore\": 0"
-      "    },"
-      "    {"
-      "      \"server_uri\": \"fake:///lb2\","
-      "      \"channel_creds\": ["
-      "        {"
-      "          \"type\": \"fake\","
-      "          \"ignore\": 0"
-      "        }"
-      "      ],"
-      "      \"ignore\": 0"
       "    }"
       "  ],"
       "  \"authorities\": {"
@@ -123,15 +109,6 @@ TEST(XdsBootstrapTest, Basic) {
       "            \"xds_v3\","
       "            \"ignore_resource_deletion\""
       "          ]"
-      "        },"
-      "        {"
-      "          \"server_uri\": \"fake:///xds_server2\","
-      "          \"channel_creds\": ["
-      "            {"
-      "              \"type\": \"fake\""
-      "            }"
-      "          ],"
-      "          \"server_features\": [\"xds_v3\"]"
       "        }"
       "      ]"
       "    },"
@@ -744,8 +721,7 @@ TEST(XdsBootstrapTest, XdsServerToJsonAndParse) {
   EXPECT_EQ(*xds_server, *output_xds_server);
 }
 
-TEST(XdsBootstrapTest, NoXdsServersEnvVar) {
-  ScopedEnvVar fallback_enabled("GRPC_EXPERIMENTAL_XDS_FALLBACK", "1");
+TEST(XdsBootstrapTest, MultipleXdsServers) {
   const char* json_str =
       "{"
       "  \"xds_servers\": ["
