@@ -17,6 +17,8 @@
 #ifndef GRPC_TEST_CPP_END2END_XDS_XDS_SERVER_H
 #define GRPC_TEST_CPP_END2END_XDS_XDS_SERVER_H
 
+#include <grpcpp/support/status.h>
+
 #include <deque>
 #include <set>
 #include <string>
@@ -24,14 +26,11 @@
 #include <vector>
 
 #include "absl/log/check.h"
+#include "absl/log/log.h"
 #include "absl/types/optional.h"
-
-#include <grpc/support/log.h>
-#include <grpcpp/support/status.h>
-
 #include "src/core/lib/address_utils/parse_address.h"
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/sync.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/sync.h"
 #include "src/proto/grpc/testing/xds/v3/ads.grpc.pb.h"
 #include "src/proto/grpc/testing/xds/v3/cluster.grpc.pb.h"
 #include "src/proto/grpc/testing/xds/v3/discovery.grpc.pb.h"
@@ -132,9 +131,9 @@ class AdsServiceImpl
   // Sets a callback to be invoked on request messages with respoonse_nonce
   // set.  The callback is passed the resource type and version.
   void SetCheckVersionCallback(
-      std::function<void(absl::string_view, int)> check_version_callack) {
+      std::function<void(absl::string_view, int)> check_version_callback) {
     grpc_core::MutexLock lock(&ads_mu_);
-    check_version_callack_ = std::move(check_version_callack);
+    check_version_callback_ = std::move(check_version_callback);
   }
 
   // Get the list of response state for each resource type.
@@ -233,16 +232,16 @@ class AdsServiceImpl
 
   Status StreamAggregatedResources(ServerContext* context,
                                    Stream* stream) override {
-    gpr_log(GPR_INFO, "ADS[%s]: StreamAggregatedResources starts",
-            debug_label_.c_str());
+    LOG(INFO) << "ADS[" << debug_label_
+              << "]: StreamAggregatedResources starts";
     {
       grpc_core::MutexLock lock(&ads_mu_);
       if (forced_ads_failure_.has_value()) {
-        gpr_log(GPR_INFO,
-                "ADS[%s]: StreamAggregatedResources forcing early failure "
-                "with status code: %d, message: %s",
-                debug_label_.c_str(), forced_ads_failure_.value().error_code(),
-                forced_ads_failure_.value().error_message().c_str());
+        LOG(INFO) << "ADS[" << debug_label_
+                  << "]: StreamAggregatedResources forcing early failure "
+                     "with status code: "
+                  << forced_ads_failure_.value().error_code() << ", message: "
+                  << forced_ads_failure_.value().error_message();
         return forced_ads_failure_.value();
       }
     }
@@ -283,10 +282,9 @@ class AdsServiceImpl
           DiscoveryRequest request = std::move(requests.front());
           requests.pop_front();
           did_work = true;
-          gpr_log(GPR_INFO,
-                  "ADS[%s]: Received request for type %s with content %s",
-                  debug_label_.c_str(), request.type_url().c_str(),
-                  request.DebugString().c_str());
+          LOG(INFO) << "ADS[" << debug_label_ << "]: Received request for type "
+                    << request.type_url() << " with content "
+                    << request.DebugString();
           SentState& sent_state = sent_state_map[request.type_url()];
           // Process request.
           ProcessRequest(request, &update_queue, &subscription_map, &sent_state,
@@ -294,8 +292,8 @@ class AdsServiceImpl
         }
       }
       if (response.has_value()) {
-        gpr_log(GPR_INFO, "ADS[%s]: Sending response: %s", debug_label_.c_str(),
-                response->DebugString().c_str());
+        LOG(INFO) << "ADS[" << debug_label_
+                  << "]: Sending response: " << response->DebugString();
         stream->Write(response.value());
       }
       response.reset();
@@ -315,8 +313,8 @@ class AdsServiceImpl
         }
       }
       if (response.has_value()) {
-        gpr_log(GPR_INFO, "ADS[%s]: Sending update response: %s",
-                debug_label_.c_str(), response->DebugString().c_str());
+        LOG(INFO) << "ADS[" << debug_label_
+                  << "]: Sending update response: " << response->DebugString();
         stream->Write(response.value());
       }
       {
@@ -350,8 +348,7 @@ class AdsServiceImpl
         }
       }
     }
-    gpr_log(GPR_INFO, "ADS[%s]: StreamAggregatedResources done",
-            debug_label_.c_str());
+    LOG(INFO) << "ADS[" << debug_label_ << "]: StreamAggregatedResources done";
     RemoveClient(context->peer());
     return Status::OK;
   }
@@ -371,9 +368,9 @@ class AdsServiceImpl
         CHECK(absl::SimpleAtoi(request.version_info(),
                                &client_resource_type_version));
       }
-      if (check_version_callack_ != nullptr) {
-        check_version_callack_(request.type_url(),
-                               client_resource_type_version);
+      if (check_version_callback_ != nullptr) {
+        check_version_callback_(request.type_url(),
+                                client_resource_type_version);
       }
     } else {
       int client_nonce;
@@ -382,9 +379,9 @@ class AdsServiceImpl
       ResponseState response_state;
       if (!request.has_error_detail()) {
         response_state.state = ResponseState::ACKED;
-        gpr_log(GPR_INFO, "ADS[%s]: client ACKed resource_type=%s version=%s",
-                debug_label_.c_str(), request.type_url().c_str(),
-                request.version_info().c_str());
+        LOG(INFO) << "ADS[" << debug_label_
+                  << "]: client ACKed resource_type=" << request.type_url()
+                  << " version=" << request.version_info();
       } else {
         response_state.state = ResponseState::NACKED;
         if (check_nack_status_code_ != nullptr) {
@@ -392,11 +389,10 @@ class AdsServiceImpl
               static_cast<absl::StatusCode>(request.error_detail().code()));
         }
         response_state.error_message = request.error_detail().message();
-        gpr_log(GPR_INFO,
-                "ADS[%s]: client NACKed resource_type=%s version=%s: %s",
-                debug_label_.c_str(), request.type_url().c_str(),
-                request.version_info().c_str(),
-                response_state.error_message.c_str());
+        LOG(INFO) << "ADS[" << debug_label_
+                  << "]: client NACKed resource_type=" << request.type_url()
+                  << " version=" << request.version_info() << ": "
+                  << response_state.error_message;
       }
       resource_type_response_state_[request.type_url()].emplace_back(
           std::move(response_state));
@@ -426,9 +422,9 @@ class AdsServiceImpl
                          &resource_state, update_queue) ||
           ClientNeedsResourceUpdate(resource_type_state, resource_state,
                                     sent_state->resource_type_version)) {
-        gpr_log(GPR_INFO, "ADS[%s]: Sending update for type=%s name=%s",
-                debug_label_.c_str(), request.type_url().c_str(),
-                resource_name.c_str());
+        LOG(INFO) << "ADS[" << debug_label_
+                  << "]: Sending update for type=" << request.type_url()
+                  << " name=" << resource_name;
         resources_added_to_response.emplace(resource_name);
         if (!response->has_value()) response->emplace();
         if (resource_state.resource.has_value()) {
@@ -441,10 +437,9 @@ class AdsServiceImpl
           }
         }
       } else {
-        gpr_log(GPR_INFO,
-                "ADS[%s]: client does not need update for type=%s name=%s",
-                debug_label_.c_str(), request.type_url().c_str(),
-                resource_name.c_str());
+        LOG(INFO) << "ADS[" << debug_label_
+                  << "]: client does not need update for type="
+                  << request.type_url() << " name=" << resource_name;
       }
     }
     // Process unsubscriptions for any resource no longer
@@ -467,8 +462,9 @@ class AdsServiceImpl
                      SubscriptionMap* subscription_map, SentState* sent_state,
                      absl::optional<DiscoveryResponse>* response)
       ABSL_EXCLUSIVE_LOCKS_REQUIRED(ads_mu_) {
-    gpr_log(GPR_INFO, "ADS[%s]: Received update for type=%s name=%s",
-            debug_label_.c_str(), resource_type.c_str(), resource_name.c_str());
+    LOG(INFO) << "ADS[" << debug_label_
+              << "]: Received update for type=" << resource_type
+              << " name=" << resource_name;
     auto& subscription_name_map = (*subscription_map)[resource_type];
     auto& resource_type_state = resource_map_[resource_type];
     auto& resource_name_map = resource_type_state.resource_name_map;
@@ -477,9 +473,9 @@ class AdsServiceImpl
       ResourceState& resource_state = resource_name_map[resource_name];
       if (ClientNeedsResourceUpdate(resource_type_state, resource_state,
                                     sent_state->resource_type_version)) {
-        gpr_log(GPR_INFO, "ADS[%s]: Sending update for type=%s name=%s",
-                debug_label_.c_str(), resource_type.c_str(),
-                resource_name.c_str());
+        LOG(INFO) << "ADS[" << debug_label_
+                  << "]: Sending update for type=" << resource_type
+                  << " name=" << resource_name;
         response->emplace();
         if (resource_state.resource.has_value()) {
           auto* resource = (*response)->add_resources();
@@ -510,8 +506,7 @@ class AdsServiceImpl
         requests->emplace_back(std::move(request));
       }
     }
-    gpr_log(GPR_INFO, "ADS[%s]: Null read, stream closed",
-            debug_label_.c_str());
+    LOG(INFO) << "ADS[" << debug_label_ << "]: Null read, stream closed";
     grpc_core::MutexLock lock(&ads_mu_);
     *stream_closed = true;
   }
@@ -591,7 +586,7 @@ class AdsServiceImpl
       resource_type_response_state_ ABSL_GUARDED_BY(ads_mu_);
   std::set<std::string /*resource_type*/> resource_types_to_ignore_
       ABSL_GUARDED_BY(ads_mu_);
-  std::function<void(absl::string_view, int)> check_version_callack_
+  std::function<void(absl::string_view, int)> check_version_callback_
       ABSL_GUARDED_BY(ads_mu_);
   // An instance data member containing the current state of all resources.
   // Note that an entry will exist whenever either of the following is true:
@@ -621,8 +616,19 @@ class LrsServiceImpl
     // Stats for a given locality.
     struct LocalityStats {
       struct LoadMetric {
-        uint64_t num_requests_finished_with_metric;
-        double total_metric_value;
+        uint64_t num_requests_finished_with_metric = 0;
+        double total_metric_value = 0;
+
+        LoadMetric() = default;
+
+        // Works for both EndpointLoadMetricStats and
+        // UnnamedEndpointLoadMetricStats.
+        template <typename T>
+        explicit LoadMetric(const T& stats)
+            : num_requests_finished_with_metric(
+                  stats.num_requests_finished_with_metric()),
+              total_metric_value(stats.total_metric_value()) {}
+
         LoadMetric& operator+=(const LoadMetric& other) {
           num_requests_finished_with_metric +=
               other.num_requests_finished_with_metric;
@@ -644,10 +650,13 @@ class LrsServiceImpl
             total_error_requests(
                 upstream_locality_stats.total_error_requests()),
             total_issued_requests(
-                upstream_locality_stats.total_issued_requests()) {
+                upstream_locality_stats.total_issued_requests()),
+            cpu_utilization(upstream_locality_stats.cpu_utilization()),
+            mem_utilization(upstream_locality_stats.mem_utilization()),
+            application_utilization(
+                upstream_locality_stats.application_utilization()) {
         for (const auto& s : upstream_locality_stats.load_metric_stats()) {
-          load_metrics[s.metric_name()] += LoadMetric{
-              s.num_requests_finished_with_metric(), s.total_metric_value()};
+          load_metrics[s.metric_name()] += LoadMetric(s);
         }
       }
 
@@ -656,6 +665,9 @@ class LrsServiceImpl
         total_requests_in_progress += other.total_requests_in_progress;
         total_error_requests += other.total_error_requests;
         total_issued_requests += other.total_issued_requests;
+        cpu_utilization += other.cpu_utilization;
+        mem_utilization += other.mem_utilization;
+        application_utilization += other.application_utilization;
         for (const auto& p : other.load_metrics) {
           load_metrics[p.first] += p.second;
         }
@@ -666,6 +678,9 @@ class LrsServiceImpl
       uint64_t total_requests_in_progress = 0;
       uint64_t total_error_requests = 0;
       uint64_t total_issued_requests = 0;
+      LoadMetric cpu_utilization;
+      LoadMetric mem_utilization;
+      LoadMetric application_utilization;
       std::map<std::string, LoadMetric> load_metrics;
     };
 
@@ -751,7 +766,7 @@ class LrsServiceImpl
   using Stream = ServerReaderWriter<LoadStatsResponse, LoadStatsRequest>;
 
   Status StreamLoadStats(ServerContext* /*context*/, Stream* stream) override {
-    gpr_log(GPR_INFO, "LRS[%s]: StreamLoadStats starts", debug_label_.c_str());
+    LOG(INFO) << "LRS[" << debug_label_ << "]: StreamLoadStats starts";
     if (stream_started_callback_ != nullptr) stream_started_callback_();
     // Take a reference of the LrsServiceImpl object, reference will go
     // out of scope after this method exits.
@@ -778,8 +793,9 @@ class LrsServiceImpl
       // Wait for report.
       request.Clear();
       while (stream->Read(&request)) {
-        gpr_log(GPR_INFO, "LRS[%s]: received client load report message: %s",
-                debug_label_.c_str(), request.DebugString().c_str());
+        LOG(INFO) << "LRS[" << debug_label_
+                  << "]: received client load report message: "
+                  << request.DebugString();
         std::vector<ClientStats> stats;
         for (const auto& cluster_stats : request.cluster_stats()) {
           stats.emplace_back(cluster_stats);
@@ -796,7 +812,7 @@ class LrsServiceImpl
         lrs_cv_.Wait(&lrs_mu_);
       }
     }
-    gpr_log(GPR_INFO, "LRS[%s]: StreamLoadStats done", debug_label_.c_str());
+    LOG(INFO) << "LRS[" << debug_label_ << "]: StreamLoadStats done";
     return Status::OK;
   }
 
