@@ -16,29 +16,24 @@
 //
 //
 
-#include <string.h>
-#include <sys/types.h>
-
-#include <vector>
-
 #include <address_sorting/address_sorting.h>
 #include <gmock/gmock.h>
-
-#include "absl/log/check.h"
-#include "absl/log/log.h"
-
 #include <grpc/grpc.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/string_util.h>
 #include <grpc/support/sync.h>
 #include <grpc/support/time.h>
+#include <string.h>
+#include <sys/types.h>
 
+#include <vector>
+
+#include "absl/log/check.h"
+#include "absl/log/log.h"
 #include "src/core/client_channel/client_channel_filter.h"
 #include "src/core/lib/address_utils/sockaddr_utils.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/config/config_vars.h"
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/host_port.h"
 #include "src/core/lib/iomgr/combiner.h"
 #include "src/core/lib/iomgr/executor.h"
 #include "src/core/lib/iomgr/iomgr.h"
@@ -47,6 +42,8 @@
 #include "src/core/resolver/endpoint_addresses.h"
 #include "src/core/resolver/resolver.h"
 #include "src/core/resolver/resolver_registry.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/host_port.h"
 #include "src/core/util/string.h"
 #include "test/core/test_util/port.h"
 #include "test/core/test_util/test_config.h"
