@@ -18,14 +18,13 @@
 
 #include "test/cpp/util/cli_credentials.h"
 
-#include "absl/flags/flag.h"
-#include "absl/log/log.h"
-
 #include <grpc/slice.h>
 #include <grpcpp/support/slice.h>
 
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/load_file.h"
+#include "absl/flags/flag.h"
+#include "absl/log/log.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/load_file.h"
 
 ABSL_RETIRED_FLAG(bool, enable_ssl, false,
                   "Replaced by --channel_creds_type=ssl.");
