@@ -399,13 +399,13 @@ for dirname in [
     "src/cpp/ext/gcp",
     "src/cpp/ext/csm",
     "src/cpp/ext/otel",
-    "test/core/backoff",
+    "test/core/util",
     "test/core/call",
     "test/core/call/yodel",
     "test/core/client_channel",
     "test/core/experiments",
     "test/core/load_balancing",
-    "test/core/uri",
+    "test/core/util",
     "test/core/test_util",
     "test/core/end2end",
     "test/core/event_engine",
