@@ -624,6 +624,7 @@ from google.api import documentation_pb2
 from google.api import endpoint_pb2
 from google.api import error_reason_pb2
 from google.api import field_behavior_pb2
+from google.api import field_info_pb2
 from google.api import http_pb2
 from google.api import httpbody_pb2
 from google.api import label_pb2
@@ -633,15 +634,21 @@ from google.api import logging_pb2
 from google.api import metric_pb2
 from google.api import monitored_resource_pb2
 from google.api import monitoring_pb2
+from google.api import policy_pb2
 from google.api import quota_pb2
 from google.api import resource_pb2
+from google.api import routing_pb2
 from google.api import service_pb2
 from google.api import source_info_pb2
 from google.api import system_parameter_pb2
 from google.api import usage_pb2
 from google.api import visibility_pb2
+from google.api.apikeys.v2 import apikeys_pb2
+from google.api.apikeys.v2 import resources_pb2
+from google.api.cloudquotas.v1 import cloudquotas_pb2
+from google.api.cloudquotas.v1 import resources_pb2
+from google.api.expr.conformance.v1alpha1 import conformance_service_pb2
 from google.api.expr.v1alpha1 import checked_pb2
-from google.api.expr.v1alpha1 import conformance_service_pb2
 from google.api.expr.v1alpha1 import eval_pb2
 from google.api.expr.v1alpha1 import explain_pb2
 from google.api.expr.v1alpha1 import syntax_pb2
@@ -659,6 +666,7 @@ from google.api.servicecontrol.v1 import metric_value_pb2
 from google.api.servicecontrol.v1 import operation_pb2
 from google.api.servicecontrol.v1 import quota_controller_pb2
 from google.api.servicecontrol.v1 import service_controller_pb2
+from google.api.servicecontrol.v2 import service_controller_pb2
 from google.api.servicemanagement.v1 import resources_pb2
 from google.api.servicemanagement.v1 import servicemanager_pb2
 from google.api.serviceusage.v1 import resources_pb2
@@ -674,8 +682,10 @@ from google.logging.v2 import logging_pb2
 from google.longrunning import operations_pb2
 from google.rpc import code_pb2
 from google.rpc import error_details_pb2
+from google.rpc import http_pb2
 from google.rpc import status_pb2
 from google.rpc.context import attribute_context_pb2
+from google.rpc.context import audit_context_pb2
 from google.type import calendar_period_pb2
 from google.type import color_pb2
 from google.type import date_pb2
